@@ -1,15 +1,13 @@
 import datetime as dt
 import logging
-from typing import Literal
 
-import pandas as pd
 import polars as pl
 
 import pyield.converters as cv
 from pyield import b3, bday, interpolator
 from pyield.config import TIMEZONE_BZ
-from pyield.converters import DateArray, DateScalar
 from pyield.data_cache import get_cached_dataset
+from pyield.types import DateArray, DateScalar, has_null_args
 
 logger = logging.getLogger(__name__)
 
@@ -35,7 +33,6 @@ def _load_with_intraday(dates: list[dt.date]) -> pl.DataFrame:
     if has_today and is_today_not_in_cache and is_today_last_bday:
         try:
             df_intraday = b3.futures(contract_code="DI1", date=today)
-            df_intraday = pl.from_pandas(df_intraday)
             if "SettlementPrice" not in df_intraday.columns or df_intraday.is_empty():
                 logger.warning(
                     f"Ainda sem dados de ajustes intraday para {today}."
@@ -55,7 +52,7 @@ def _load_with_intraday(dates: list[dt.date]) -> pl.DataFrame:
 
 
 def _get_data(dates: DateScalar | DateArray) -> pl.DataFrame:
-    converted_dates = cv.convert_input_dates(dates)
+    converted_dates = cv.convert_dates(dates)
 
     match converted_dates:
         case None:
@@ -63,7 +60,7 @@ def _get_data(dates: DateScalar | DateArray) -> pl.DataFrame:
             return pl.DataFrame()
         case dt.date():
             dates_list = [converted_dates]
-        case pd.Series():
+        case pl.Series():
             dates_list = (
                 pl.Series("TradeDate", converted_dates).unique().sort().to_list()
             )
@@ -77,8 +74,7 @@ def data(
     dates: DateScalar | DateArray,
     month_start: bool = False,
     pre_filter: bool = False,
-    return_format: Literal["pandas", "polars"] = "pandas",
-) -> pd.DataFrame | pl.DataFrame:
+) -> pl.DataFrame:
     """
     Retrieves DI Futures contract data for a specific trade date.
 
@@ -94,25 +90,39 @@ def data(
             those whose expiration dates match known prefixed Treasury bond (LTN, NTN-F)
             maturities from the TPF dataset nearest to the given trade date.
             Defaults to False.
-        return_format (Literal['pandas','polars'], optional): Specifies the return
-            format. Can be 'pandas' (default) or 'polars'.
 
     Returns:
-        pd.DataFrame | pl.DataFrame: A DataFrame containing the DI futures contract
+        pl.DataFrame: A DataFrame containing the DI futures contract
             data for the specified dates, sorted by trade dates and expiration dates.
             Returns an empty DataFrame if no data is found
 
     Examples:
         >>> from pyield import di1
         >>> df = di1.data(dates="16-10-2024", month_start=True)
-        >>> df.iloc[:5, :5]  # Show the first five rows and columns
-           TradeDate ExpirationDate TickerSymbol  BDaysToExp  OpenContracts
-        0 2024-10-16     2024-11-01       DI1X24          12        1744269
-        1 2024-10-16     2024-12-01       DI1Z24          31        1429375
-        2 2024-10-16     2025-01-01       DI1F25          52        5423969
-        3 2024-10-16     2025-02-01       DI1G25          74         279491
-        4 2024-10-16     2025-03-01       DI1H25          94         344056
-    """
+        >>> df
+        shape: (38, 19)
+        ┌────────────┬────────────────┬──────────────┬────────────┬───┬──────────────┬──────────────┬────────────────┬─────────────┐
+        │ TradeDate  ┆ ExpirationDate ┆ TickerSymbol ┆ BDaysToExp ┆ … ┆ CloseBidRate ┆ CloseAskRate ┆ SettlementRate ┆ ForwardRate │
+        │ ---        ┆ ---            ┆ ---          ┆ ---        ┆   ┆ ---          ┆ ---          ┆ ---            ┆ ---         │
+        │ date       ┆ date           ┆ str          ┆ i64        ┆   ┆ f64          ┆ f64          ┆ f64            ┆ f64         │
+        ╞════════════╪════════════════╪══════════════╪════════════╪═══╪══════════════╪══════════════╪════════════════╪═════════════╡
+        │ 2024-10-16 ┆ 2024-11-01     ┆ DI1X24       ┆ 12         ┆ … ┆ 0.10656      ┆ 0.10652      ┆ 0.10653        ┆ 0.10653     │
+        │ 2024-10-16 ┆ 2024-12-01     ┆ DI1Z24       ┆ 31         ┆ … ┆ 0.10914      ┆ 0.10912      ┆ 0.1091         ┆ 0.110726    │
+        │ 2024-10-16 ┆ 2025-01-01     ┆ DI1F25       ┆ 52         ┆ … ┆ 0.1117       ┆ 0.11164      ┆ 0.11164        ┆ 0.1154      │
+        │ 2024-10-16 ┆ 2025-02-01     ┆ DI1G25       ┆ 74         ┆ … ┆ 0.11375      ┆ 0.11355      ┆ 0.11362        ┆ 0.118314    │
+        │ 2024-10-16 ┆ 2025-03-01     ┆ DI1H25       ┆ 94         ┆ … ┆ 0.11595      ┆ 0.1157       ┆ 0.1157         ┆ 0.12343     │
+        │ …          ┆ …              ┆ …            ┆ …          ┆ … ┆ …            ┆ …            ┆ …              ┆ …           │
+        │ 2024-10-16 ┆ 2035-01-01     ┆ DI1F35       ┆ 2556       ┆ … ┆ 0.1265       ┆ 0.1264       ┆ 0.1265         ┆ 0.124455    │
+        │ 2024-10-16 ┆ 2036-01-01     ┆ DI1F36       ┆ 2805       ┆ … ┆ null         ┆ null         ┆ 0.1263         ┆ 0.124249    │
+        │ 2024-10-16 ┆ 2037-01-01     ┆ DI1F37       ┆ 3058       ┆ … ┆ null         ┆ null         ┆ 0.1263         ┆ 0.1263      │
+        │ 2024-10-16 ┆ 2038-01-01     ┆ DI1F38       ┆ 3307       ┆ … ┆ null         ┆ null         ┆ 0.1263         ┆ 0.1263      │
+        │ 2024-10-16 ┆ 2039-01-01     ┆ DI1F39       ┆ 3558       ┆ … ┆ null         ┆ null         ┆ 0.1263         ┆ 0.1263      │
+        └────────────┴────────────────┴──────────────┴────────────┴───┴──────────────┴──────────────┴────────────────┴─────────────┘
+
+    """  # noqa: E501
+    if has_null_args(dates):
+        logger.warning("No valid 'dates' provided. Returning empty DataFrame.")
+        return pl.DataFrame()
     df = _get_data(dates=dates)
 
     if month_start:
@@ -142,7 +152,7 @@ def data(
             check_sortedness=False,  # já garantimos a ordenação
         )
 
-    return cv.to_return_format(df, return_format)
+    return df
 
 
 def _build_input_dataframe(
@@ -150,35 +160,23 @@ def _build_input_dataframe(
     expirations: DateScalar | DateArray,
 ) -> pl.DataFrame:
     # 1. Converte as entradas primeiro
-    converted_dates = cv.convert_input_dates(dates)
-    converted_expirations = cv.convert_input_dates(expirations)
+    converted_dates = cv.convert_dates(dates)
+    converted_expirations = cv.convert_dates(expirations)
 
     # 2. Lida com os 4 casos de forma SIMPLES E LEGÍVEL
     match (converted_dates, converted_expirations):
         # CASO 1: Data escalar, vencimentos em array
-        case dt.date() as d, pd.Series() as e:
-            if e.empty:
-                dfi = pl.DataFrame()
-            else:
-                # Cria o DF com o array, e ADICIONA o escalar com pl.lit()
-                dfi = pl.DataFrame({"ExpirationDate": e}).with_columns(TradeDate=d)
+        case dt.date() as d, pl.Series() as e:
+            dfi = pl.DataFrame({"ExpirationDate": e}).with_columns(TradeDate=d)
 
         # CASO 2: Datas em array, vencimento escalar
-        case pd.Series() as d, dt.date() as e:
-            if d.empty:
-                dfi = pl.DataFrame()
-            else:
-                # Mesma lógica, invertida
-                dfi = pl.DataFrame({"TradeDate": d}).with_columns(ExpirationDate=e)
+        case pl.Series() as d, dt.date() as e:
+            # Mesma lógica, invertida
+            dfi = pl.DataFrame({"TradeDate": d}).with_columns(ExpirationDate=e)
 
         # CASO 3: Ambos são arrays
-        case pd.Series() as d, pd.Series() as e:
-            if d.empty or e.empty:
-                dfi = pl.DataFrame()
-            elif len(d) != len(e):
-                raise ValueError("'dates' e 'expirations' devem ter o mesmo tamanho.")
-            else:
-                dfi = pl.DataFrame({"TradeDate": d, "ExpirationDate": e})
+        case pl.Series() as d, pl.Series() as e:
+            dfi = pl.DataFrame({"TradeDate": d, "ExpirationDate": e})
 
         # CASO 4: Ambos são escalares
         case dt.date() as d, dt.date() as e:
@@ -192,11 +190,10 @@ def _build_input_dataframe(
 
 
 def interpolate_rates(
-    dates: DateScalar | DateArray | None,
-    expirations: DateScalar | DateArray | None,
+    dates: DateScalar | DateArray,
+    expirations: DateScalar | DateArray,
     extrapolate: bool = True,
-    return_format: Literal["pandas", "polars"] = "pandas",
-) -> pd.Series | pl.Series:
+) -> pl.Series:
     """
     Interpolates DI rates for specified trade dates and expiration dates.
 
@@ -218,34 +215,32 @@ def interpolate_rates(
             range of known DI rates for a given trade date. Defaults to True.
 
     Returns:
-        pd.Series: A Series containing the interpolated DI rates (as floats).
+        pl.Series: A Series containing the interpolated DI rates (as floats).
             Values will be NaN where interpolation is not possible
             (e.g., no DI data for the trade date).
 
-    Raises:
-        ValueError: If `dates` and `expirations` are both array-like but have
-            different lengths.
-
     Examples:
-        >>> from pyield import di1
-        >>> # Note: by default, pandas shows floats with 6 decimal places
-        >>> # Interpolate rates for multiple trade and expiration dates
-        >>> # There is a contract with expiration 01-01-2027 in 08-05-2025
+        - Interpolate rates for multiple trade and expiration dates
+        >>> # For contract with expiration 01-01-2027 in 08-05-2025
         >>> # The rate is not interpolated (settlement rate is used)
         >>> # There is no contract with expiration 25-11-2027 in 09-05-2025
         >>> # The rate is interpolated (flat-forward method)
         >>> # There is no data for trade date 10-05-2025 (Saturday) -> NaN
         >>> # Note: 0.13461282461562996 is shown as 0.134613
+        >>> from pyield import di1
         >>> di1.interpolate_rates(
         ...     dates=["08-05-2025", "09-05-2025", "10-05-2025"],
         ...     expirations=["01-01-2027", "25-11-2027", "01-01-2030"],
         ... )
-        0    0.13972
-        1    0.134613
-        2    <NA>
-        Name: irate, dtype: double[pyarrow]
+        shape: (3,)
+        Series: 'FlatFwdRate' [f64]
+        [
+            0.13972
+            0.134613
+            null
+        ]
 
-        >>> # Interpolate rates for a single trade date and multiple expiration dates
+        - Interpolate rates for a single trade date and multiple expiration dates
         >>> # There is no DI Contract in 09-05-2025 with expiration 01-01-2050
         >>> # The longest available contract is used to extrapolate the rate
         >>> # Note: extrapolation is allowed by default
@@ -253,42 +248,56 @@ def interpolate_rates(
         ...     dates="25-04-2025",
         ...     expirations=["01-01-2027", "01-01-2050"],
         ... )
-        0    0.13901
-        1    0.13881
-        Name: irate, dtype: double[pyarrow]
+        shape: (2,)
+        Series: 'FlatFwdRate' [f64]
+        [
+            0.13901
+            0.13881
+        ]
 
-        >>> # With extrapolation set to False, the second rate will be NaN
+        >>> # With extrapolation set to False, the second rate will be null
         >>> # Note: 0.13576348733268917 is shown as 0.135763
         >>> di1.interpolate_rates(
         ...     dates="25-04-2025",
         ...     expirations=["01-11-2027", "01-01-2050"],
         ...     extrapolate=False,
         ... )
-        0    0.135763
-        1    NaN
-        Name: irate, dtype: double[pyarrow]
+        shape: (2,)
+        Series: 'FlatFwdRate' [f64]
+        [
+            0.135763
+            null
+        ]
+
+    Raises:
+        ValueError: If `dates` and `expirations` are both array-like but have
+            different lengths.
 
     Notes:
         - All available settlement rates are used for the flat-forward interpolation.
         - The function handles broadcasting of scalar and array-like inputs.
     """
+    if has_null_args(dates, expirations):
+        logger.warning(
+            "Both 'dates' and 'expirations' must be provided. Returning empty Series."
+        )
+        return pl.Series(dtype=pl.Float64)
+
     dfi = _build_input_dataframe(dates, expirations)
-
-    # 2. Se a helper retornou None, a entrada é inválida.
+    # 2. Se a helper retornou um DataFrame vazio, retornar uma Series vazia
     if dfi.is_empty():
-        logger.warning("Invalid or empty dates provided. Returning empty Series.")
-        return pd.Series(dtype="float64[pyarrow]")
+        logger.warning("Invalid inputs provided. Returning empty Series.")
+        return pl.Series(dtype=pl.Float64)
 
-    # bday.count retorna uma Series de inteiros do pandas
     s_bdays = bday.count(dfi["TradeDate"], dfi["ExpirationDate"])
-    dfi = dfi.with_columns(pl.Series("bdays", s_bdays), irate=None)
+    dfi = dfi.with_columns(BDaysToExp=s_bdays, FlatFwdRate=None)
 
     # Load DI rates dataset filtered by the provided reference dates
     dfr = _get_data(dates=dates)
 
     # Return an empty DataFrame if no rates are found
     if dfr.is_empty():
-        return pd.Series(dtype="float64[pyarrow]")
+        return pl.Series(dtype=pl.Float64)
 
     # Iterate over each unique reference date
     for date in dfi.get_column("TradeDate").unique().to_list():
@@ -309,21 +318,20 @@ def interpolate_rates(
 
         dfi = dfi.with_columns(
             pl.when(pl.col("TradeDate") == date)
-            .then(pl.col("bdays").map_elements(interp, return_dtype=pl.Float64))
-            .otherwise(pl.col("irate"))
-            .alias("irate")
+            .then(pl.col("BDaysToExp").map_elements(interp, return_dtype=pl.Float64))
+            .otherwise(pl.col("FlatFwdRate"))
+            .alias("FlatFwdRate")
         )
 
     # Return the series with interpolated rates
-    irates = dfi.get_column("irate")
-    return cv.to_return_format(irates, return_format)
+    return dfi.get_column("FlatFwdRate")
 
 
 def interpolate_rate(
     date: DateScalar,
     expiration: DateScalar,
     extrapolate: bool = False,
-) -> float:
+) -> float | None:
     """
     Interpolates or retrieves the DI rate for a single expiration date.
 
@@ -341,8 +349,8 @@ def interpolate_rate(
             expirations for the given `date`. Defaults to False.
 
     Returns:
-        float: The exact or interpolated DI settlement rate for the specified
-            date and expiration. Returns `float('NaN')` if:
+        float | None: The exact or interpolated DI settlement rate for the specified
+            date and expiration. Returns `None` if:
                 - No DI data is found for the `date`.
                 - The `expiration` is outside range and `extrapolate` is False.
                 - An interpolation calculation fails.
@@ -361,56 +369,36 @@ def interpolate_rate(
         >>> di1.interpolate_rate("25-04-2025", "01-01-2050", extrapolate=True)
         0.13881
     """
-    converted_date = cv.convert_input_dates(date)
-    converted_expiration = cv.convert_input_dates(expiration)
+    if has_null_args(date, expiration):
+        logger.warning("Both 'date' and 'expiration' must be provided. Returning NaN.")
+        return None
+
+    converted_date = cv.convert_dates(date)
+    converted_expiration = cv.convert_dates(expiration)
 
     if not isinstance(converted_date, dt.date) or not isinstance(
         converted_expiration, dt.date
     ):
         raise ValueError("Both 'date' and 'expiration' must be single date values.")
 
-    if not converted_date or not converted_expiration:
-        return float("nan")
-
     # Get the DI contract DataFrame
     df = _get_data(dates=converted_date)
 
     if df.is_empty():
-        return float("nan")
-
-    max_exp = df.get_column("ExpirationDate").max()
-
-    if converted_expiration > max_exp and not extrapolate:
-        logger.warning(
-            f"Expiration ({converted_expiration}) is greater than the maximum exp. "
-            f"date ({max_exp}) and extrapolation is not allowed. Returning NaN."
-        )
-        return float("nan")
-
-    rate = df.filter(pl.col("ExpirationDate") == converted_expiration).get_column(
-        "SettlementRate"
-    )
-
-    if not rate.is_empty():
-        logger.info(f"Exact match found for expiration {converted_expiration}.")
-        return rate.item(0)
+        return None
 
     ff_interp = interpolator.Interpolator(
         method="flat_forward",
-        known_bdays=df.get_column("BDaysToExp"),
-        known_rates=df.get_column("SettlementRate"),
+        known_bdays=df["BDaysToExp"],
+        known_rates=df["SettlementRate"],
         extrapolate=extrapolate,
     )
-    bd = bday.count(converted_date, converted_expiration)
-    if not bd:
-        return float("nan")
 
+    bd = bday.count(converted_date, converted_expiration)
     return ff_interp(bd)
 
 
-def available_trade_dates(
-    return_format: Literal["pandas", "polars"] = "pandas",
-) -> pd.Series | pl.Series:
+def available_trade_dates() -> pl.Series:
     """
     Returns all available (completed) trading dates in the DI dataset.
 
@@ -418,19 +406,22 @@ def available_trade_dates(
     historical DI futures data cache, sorted chronologically.
 
     Returns:
-        pd.Series: A sorted Series of unique trade dates (dt.date)
-                   for which DI data is available.
+        pl.Series: A sorted Series of unique trade dates (dt.date)
+            for which DI data is available.
 
     Examples:
         >>> from pyield import di1
         >>> # DI Futures series starts from 1995-01-02
         >>> di1.available_trade_dates().head(5)
-        0   1995-01-02
-        1   1995-01-03
-        2   1995-01-04
-        3   1995-01-05
-        4   1995-01-06
-        Name: available_dates, dtype: date32[day][pyarrow]
+        shape: (5,)
+        Series: 'available_dates' [date]
+        [
+            1995-01-02
+            1995-01-03
+            1995-01-04
+            1995-01-05
+            1995-01-06
+        ]
     """
     available_dates = (
         get_cached_dataset("di1")
@@ -439,4 +430,4 @@ def available_trade_dates(
         .sort()
         .alias("available_dates")
     )
-    return cv.to_return_format(available_dates, return_format)
+    return available_dates
