@@ -1,7 +1,8 @@
 import ftplib
 import logging
 
-from pyield.converters import DateScalar, convert_input_dates
+from pyield.converters import convert_dates
+from pyield.types import DateScalar, has_null_args
 
 logger = logging.getLogger(__name__)
 
@@ -9,7 +10,7 @@ logger = logging.getLogger(__name__)
 DI_OVER_DECIMAL_PLACES = 4
 
 
-def di_over(date: DateScalar) -> float:
+def di_over(date: DateScalar) -> float | None:
     """
     Gets the DI (Interbank Deposit) rate for a specific date from B3/CETIP FTP server.
 
@@ -17,7 +18,7 @@ def di_over(date: DateScalar) -> float:
         date (str): Date in DD/MM/YYYY format
 
     Returns:
-        float: DI rate for the specified date or NaN (Not a Number) if no data is found.
+        float | None: DI rate for the specified date or None if no data is found.
 
     Raises:
         ValueError: If date is not in the correct format
@@ -28,10 +29,12 @@ def di_over(date: DateScalar) -> float:
         >>> di_over("28/02/2025")
         0.1315
     """
+    if has_null_args(date):
+        return None
     ftp = None
     try:
         # Convert date to file format
-        date_obj = convert_input_dates(date)
+        date_obj = convert_dates(date)
         filename = date_obj.strftime("%Y%m%d.txt")
 
         # Connect to FTP and get the file
@@ -53,7 +56,7 @@ def di_over(date: DateScalar) -> float:
             return round(rate, DI_OVER_DECIMAL_PLACES)
         else:
             logger.error(f"No data found for date {date}")
-            return float("nan")
+            return None
 
     except ValueError as e:
         logger.error(f"Date format error: {e}")
