@@ -1,13 +1,15 @@
 import pandas as pd
+import polars as pl
 import pytest
 
-import pyield
+import pyield as yd
 
 
 @pytest.fixture(autouse=True)
 def add_np(doctest_namespace):
-    doctest_namespace["yd"] = pyield
+    doctest_namespace["yd"] = yd
     doctest_namespace["pd"] = pd
+    doctest_namespace["pl"] = pl
 
 
 @pytest.fixture(scope="session", autouse=True)
@@ -16,10 +18,7 @@ def set_pandas_display_options():
     Define as opções de exibição do Pandas para a sessão de testes.
     Isso afeta como os DataFrames são impressos nos doctests.
     """
-    pd.set_option("display.max_columns", 8)  # Exibe até 8 colunas
-    pd.set_option("display.width", 1000)  # Define a largura máxima do display
-    pd.set_option("display.max_rows", 20)  # Exibe até 20 linhas
-    pd.set_option("display.max_colwidth", None)
+    pl.Config.set_tbl_width_chars(150)  # largura grande
 
 
 def pytest_configure(config):
